tests.models.input package — django_analyses 0.0.3 documentation

# tests.models.input package

## Subpackages

- tests.models.input.definitions package
  - Submodules
  - tests.models.input.definitions.test_boolean_input_definition module
  - tests.models.input.definitions.test_file_input_definition module
  - tests.models.input.definitions.test_float_input_definition module
  - tests.models.input.definitions.test_input_definition module
  - tests.models.input.definitions.test_integer_input_definition module
  - tests.models.input.definitions.test_list_input_definition module
  - tests.models.input.definitions.test_string_input_definition module
  - Module contents
- tests.models.input.types package
  - Submodules
  - tests.models.input.types.test_boolean_input module
  - tests.models.input.types.test_file_input module
  - tests.models.input.types.test_float_input module
  - tests.models.input.types.test_integer_input module
  - tests.models.input.types.test_list_input module
  - tests.models.input.types.test_string_input module
  - Module contents

## Submodules

## tests.models.input.test_input_specification module

class `tests.models.input.test_input_specification.` `InputSpecificationTestCase`(methodName='runTest')

  Bases: `django.test.testcases.TestCase`

  Tests for the `InputSpecification` model.

  `setUp`()

    Adds the created instances to the tests’ contexts. For more information see unittest’s `setUp()` method.

  `test_default_configuration_property`()
  `test_input_definitions_property_return_type`()
  `test_input_definitions_property_returns_subclasses`()
  `test_string`()
  `test_validate_keys_with_an_invalid_key`()
  `test_validate_keys_with_valid_keys`()
  `test_validate_kwargs_with_a_missing_required_key`()
  `test_validate_kwargs_with_an_invalid_key`()
  `test_validate_kwargs_with_valid_kwargs`()
  `test_validate_required_with_a_missing_kwarg`()
  `test_validate_required_with_valid_kwargs`()

## Module contents